@@ -26,14 +26,15 @@ public:
     /**
      * @return the Type of the item
      */
-    int type() const override {
+    int type() const override
+    {
         return Type;
     }
 
     void setIsotope(IsotopeItem *item);
 
 private:
-    QGraphicsTextItem *m_textitem;
+    QGraphicsTextItem *m_textitem = nullptr;
 };
 
 #endif // INFORMATIONITEM_H
